@@ -44,9 +44,18 @@ class Parameter(_ModelParameter):
 
         values["value"] = serialize(values.get("value", MISSING))
         values["default"] = serialize(values.get("default", MISSING))
+        if values.get("enum", []):
+            # We don't need to set "enum" in values to "MISSING" if there are no values
+            # as it's a list of values. The values themselves should be serialized.
+            values["enum"] = [serialize(v) for v in values.get("enum")]
 
         return values
 
+    @classmethod
+    def _get_input_attributes(cls):
+        """Return the attributes used for input parameter annotations."""
+        return ["enum", "description", "default", "name", "value", "value_from"]
+
     def __str__(self):
         """Represent the parameter as a string by pointing to its value.
 
@@ -57,6 +66,11 @@ class Parameter(_ModelParameter):
             raise ValueError("Cannot represent `Parameter` as string as `value` is not set")
         return self.value
 
+    @classmethod
+    def from_model(cls, model: _ModelParameter) -> Parameter:
+        """Creates a `Parameter` from a `Parameter` model."""
+        return cls(**model.dict())
+
     def with_name(self, name: str) -> Parameter:
         """Returns a copy of the parameter with the name set to the value."""
         p = self.copy(deep=True)
@@ -104,10 +118,5 @@ class Parameter(_ModelParameter):
             value_from=self.value_from,
         )
 
-    @classmethod
-    def _get_input_attributes(cls):
-        """Return the attributes used for input parameter annotations."""
-        return ["enum", "description", "default", "name", "value", "value_from"]
-
 
 __all__ = ["Parameter"]
