@@ -32,7 +32,6 @@ from hera.workflows._mixins import (
     CallableTemplateMixin,
     ContainerMixin,
     EnvIOMixin,
-    ExperimentalMixin,
     ResourceMixin,
     TemplateMixin,
     VolumeMountMixin,
@@ -508,7 +507,7 @@ def _take_annotation_from(
     _: Callable[
         ScriptIns,
         Callable[[Callable[FuncIns, FuncR]], Union[Callable[FuncIns, FuncR], Callable[ScriptIns, Union[Task, Step]]]],
-    ]
+    ],
 ) -> Callable[
     [Callable],
     Callable[
@@ -692,7 +691,7 @@ class InlineScriptConstructor(ScriptConstructor):
         return textwrap.dedent(script)
 
 
-class RunnerScriptConstructor(ScriptConstructor, ExperimentalMixin):
+class RunnerScriptConstructor(ScriptConstructor):
     """`RunnerScriptConstructor` is a script constructor that runs a script in a container.
 
     The runner script, also known as "The Hera runner", takes a script/Python function definition, infers the path
@@ -703,15 +702,13 @@ class RunnerScriptConstructor(ScriptConstructor, ExperimentalMixin):
     it conains the script to run remotely.
     """
 
-    _flag: str = "script_runner"
-
     outputs_directory: Optional[str] = None
     """Used for saving outputs when defined using annotations."""
 
     volume_for_outputs: Optional[_BaseVolume] = None
     """Volume to use if saving outputs when defined using annotations."""
 
-    DEFAULT_HERA_OUTPUTS_DIRECTORY: str = "/tmp/hera/outputs"
+    DEFAULT_HERA_OUTPUTS_DIRECTORY: str = "/tmp/hera-outputs"
     """Used as the default value for when the outputs_directory is not set"""
 
     def transform_values(self, cls: Type[Script], values: Any) -> Any:
